# mypy-boto3-ivs

[![PyPI - mypy-boto3-ivs](https://img.shields.io/pypi/v/mypy-boto3-ivs.svg?color=blue)](https://pypi.org/project/mypy-boto3-ivs)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-ivs.svg?color=blue)](https://pypi.org/project/mypy-boto3-ivs)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)

![boto3.typed](https://github.com/vemel/mypy_boto3_builder/raw/master/logo.png)

Type annotations for
[boto3.IVS 1.16.28](https://boto3.amazonaws.com/v1/documentation/api/1.16.28/reference/services/ivs.html#IVS) service
compatible with
[VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright)
and other tools.

Generated by [mypy-boto3-buider 4.1.3](https://github.com/vemel/mypy_boto3_builder).

More information can be found on [boto3-stubs](https://pypi.org/project/boto3-stubs/) page.

![boto3-stubs demo](https://github.com/vemel/mypy_boto3_builder/raw/master/demo.gif)

- [mypy-boto3-ivs](#mypy-boto3-ivs)
  - [How to install](#how-to-install)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)
    - [Waiters annotations](#waiters-annotations)
    - [Service Resource annotations](#service-resource-annotations)
    - [Other resources annotations](#other-resources-annotations)
    - [Collections annotations](#collections-annotations)
    - [Typed dictionations](#typed-dictionations)

## How to install

Install `boto3-stubs` for `IVS` service.

```bash
python -m pip install boto3-stubs[ivs]
```

## Usage

### VSCode

- Install [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `boto-stubs[ivs]` in your environment: `python -m pip install 'boto3-stubs[ivs]'`

Both type checking and auto-complete should work for `IVS` service.
No explicit type annotations required, write your `boto3` code as usual.

### PyCharm

- Install `boto-stubs[ivs]` in your environment: `python -m pip install 'boto3-stubs[ivs]'`

Both type checking and auto-complete should work for `IVS` service.
No explicit type annotations required, write your `boto3` code as usual.
Auto-complete can be slow on big projects or if you have a lot of installed `boto3-stubs` submodules.

### Other IDEs

Not tested, but as long as your IDE support `mypy` or `pyright`, everything should work.

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `boto-stubs[ivs]` in your environment: `python -m pip install 'boto3-stubs[ivs]'`
- Run `mypy` as usual

Type checking should work for `IVS` service.
No explicit type annotations required, write your `boto3` code as usual.

### pyright

- Install `pyright`: `yarn global add pyright`
- Install `boto-stubs[ivs]` in your environment: `python -m pip install 'boto3-stubs[ivs]'`
- Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should work for `IVS` service.
No explicit type annotations required, write your `boto3` code as usual.

## Explicit type annotations

### Client annotations

`IVSClient` provides annotations for `boto3.client("ivs")`.

```python
import boto3

from mypy_boto3_ivs import IVSClient

client: IVSClient = boto3.client("ivs")

# now client usage is checked by mypy and IDE should provide code auto-complete

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: IVSClient = session.client("ivs")
```

### Paginators annotations

`mypy_boto3_ivs.paginator` module contains type annotations for all paginators.

```python
from mypy_boto3_ivs import IVSClient
from mypy_boto3_ivs.paginator import (
    ListChannelsPaginator,
    ListPlaybackKeyPairsPaginator,
    ListStreamKeysPaginator,
    ListStreamsPaginator,
)

client: IVSClient = boto3.client("ivs")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
# VSCode requires explicit type annotations
list_channels_paginator: ListChannelsPaginator = client.get_paginator("list_channels")
list_playback_key_pairs_paginator: ListPlaybackKeyPairsPaginator = client.get_paginator("list_playback_key_pairs")
list_stream_keys_paginator: ListStreamKeysPaginator = client.get_paginator("list_stream_keys")
list_streams_paginator: ListStreamsPaginator = client.get_paginator("list_streams")
```







### Typed dictionations

`mypy_boto3_ivs.type_defs` module contains structures and shapes assembled
to typed dictionaries for additional type checking.

```python
from mypy_boto3_ivs.type_defs import (
    BatchErrorTypeDef,
    BatchGetChannelResponseTypeDef,
    BatchGetStreamKeyResponseTypeDef,
    ChannelSummaryTypeDef,
    ChannelTypeDef,
    CreateChannelResponseTypeDef,
    CreateStreamKeyResponseTypeDef,
    GetChannelResponseTypeDef,
    GetPlaybackKeyPairResponseTypeDef,
    GetStreamKeyResponseTypeDef,
    GetStreamResponseTypeDef,
    ImportPlaybackKeyPairResponseTypeDef,
    ListChannelsResponseTypeDef,
    ListPlaybackKeyPairsResponseTypeDef,
    ListStreamKeysResponseTypeDef,
    ListStreamsResponseTypeDef,
    ListTagsForResourceResponseTypeDef,
    PaginatorConfigTypeDef,
    PlaybackKeyPairSummaryTypeDef,
    PlaybackKeyPairTypeDef,
    StreamKeySummaryTypeDef,
    StreamKeyTypeDef,
    StreamSummaryTypeDef,
    StreamTypeDef,
    UpdateChannelResponseTypeDef,
)

def get_structure() -> BatchErrorTypeDef:
    return {
      ...
    }
```
